aboutsummaryrefslogtreecommitdiff
path: root/include/configs/M5208EVBE.h
diff options
context:
space:
mode:
authorTom Rini2022-11-16 13:10:37 -0500
committerTom Rini2022-12-05 16:06:07 -0500
commitaa6e94deabb45154cea07ad44c4a5c047bca078b (patch)
tree1131ae8e3635f3d0c91f8df892ab05e4d9595785 /include/configs/M5208EVBE.h
parentaec118ebe63f7f0ab60916f9906fb3cb680abf7a (diff)
global: Move remaining CONFIG_SYS_SDRAM_* to CFG_SYS_SDRAM_*
The rest of the unmigrated CONFIG symbols in the CONFIG_SYS_SDRAM namespace do not easily transition to Kconfig. In many cases they likely should come from the device tree instead. Move these out of CONFIG namespace and in to CFG namespace. Signed-off-by: Tom Rini <trini@konsulko.com> Reviewed-by: Simon Glass <sjg@chromium.org>
Diffstat (limited to 'include/configs/M5208EVBE.h')
-rw-r--r--include/configs/M5208EVBE.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/include/configs/M5208EVBE.h b/include/configs/M5208EVBE.h
index 25c3f22bea1..6dfa3dd0f02 100644
--- a/include/configs/M5208EVBE.h
+++ b/include/configs/M5208EVBE.h
@@ -60,22 +60,22 @@
/*
* Start addresses for the final memory configuration
* (Set up by the startup code)
* Please note that CONFIG_SYS_SDRAM_BASE _must_ start at 0
*/
-#define CONFIG_SYS_SDRAM_BASE 0x40000000
-#define CONFIG_SYS_SDRAM_SIZE 32 /* SDRAM size in MB */
-#define CONFIG_SYS_SDRAM_CFG1 0x43711630
-#define CONFIG_SYS_SDRAM_CFG2 0x56670000
-#define CONFIG_SYS_SDRAM_CTRL 0xE1002000
-#define CONFIG_SYS_SDRAM_EMOD 0x80010000
-#define CONFIG_SYS_SDRAM_MODE 0x00CD0000
+#define CFG_SYS_SDRAM_BASE 0x40000000
+#define CFG_SYS_SDRAM_SIZE 32 /* SDRAM size in MB */
+#define CFG_SYS_SDRAM_CFG1 0x43711630
+#define CFG_SYS_SDRAM_CFG2 0x56670000
+#define CFG_SYS_SDRAM_CTRL 0xE1002000
+#define CFG_SYS_SDRAM_EMOD 0x80010000
+#define CFG_SYS_SDRAM_MODE 0x00CD0000
/*
* For booting Linux, the board info and command line data
* have to be in the first 8 MB of memory, since this is
* the maximum mapped by the Linux kernel during initialization ??
*/
-#define CONFIG_SYS_BOOTMAPSZ (CONFIG_SYS_SDRAM_BASE + (CONFIG_SYS_SDRAM_SIZE << 20))
+#define CONFIG_SYS_BOOTMAPSZ (CFG_SYS_SDRAM_BASE + (CFG_SYS_SDRAM_SIZE << 20))
/* FLASH organization */
#ifdef CONFIG_SYS_FLASH_CFI
@@ -100,8 +100,8 @@
#define DCACHE_STATUS (CONFIG_SYS_INIT_RAM_ADDR + \
CONFIG_SYS_INIT_RAM_SIZE - 4)
#define CONFIG_SYS_ICACHE_INV (CF_CACR_CINV | CF_CACR_INVI)
-#define CONFIG_SYS_CACHE_ACR0 (CONFIG_SYS_SDRAM_BASE | \
- CF_ADDRMASK(CONFIG_SYS_SDRAM_SIZE) | \
+#define CONFIG_SYS_CACHE_ACR0 (CFG_SYS_SDRAM_BASE | \
+ CF_ADDRMASK(CFG_SYS_SDRAM_SIZE) | \
CF_ACR_EN | CF_ACR_SM_ALL)
#define CONFIG_SYS_CACHE_ICACR (CF_CACR_CENB | CF_CACR_CINV | \
CF_CACR_DISD | CF_CACR_INVI | \
@@ -60,22 +60,22 @@
* Start addresses for the final memory configuration
* (Set up by the startup code)
- * Please note that CONFIG_SYS_SDRAM_BASE _must_ start at 0
+ * Please note that CFG_SYS_SDRAM_BASE _must_ start at 0
*/